@@ -9,7 +9,7 @@ use warnings;
 use base 'autobox';
 use Data::Object 'load';
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 sub import {
     my $class = shift;
@@ -55,7 +55,7 @@ Data::Object::Autobox - An Autobox Implementation for Perl 5
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -63,9 +63,12 @@ version 0.12
 
     my $input  = [1,1,1,1,3,3,2,1,5,6,7,8,9];
     my $output = $input->grep('$a < 5')->unique->sort; # [1,2,3]
+    my $object = $output->array;
 
-    $output->isa('Data::Object::Array');
     $output->join(',')->print; # 1,2,3
+    $object->join(',')->print; # 1,2,3
+
+    $object->isa('Data::Object::Array');
 
 =head1 DESCRIPTION
 
